@@ -9,8 +9,6 @@ def run_filterbarcodes(options):
         cells=options.cells,
         bam=options.bam,
         trim_suffix=options.trim_suffix,
-        output=options.output,
-        sam=options.sam,
         nproc=options.nproc,
         readname_barcode=options.barcode_regex,
         cellbarcode=options.barcodetag
@@ -44,5 +42,6 @@ def run_fragments(options):
         readname_barcode=options.barcode_regex,
         chromosomes=options.use_chrom,
         cells=options.cells,
-        max_distance=options.max_distance
+        max_distance=options.max_distance,
+        chunksize=options.chunksize
     )
